<?php

class questions_field_views_handler_field_select extends questions_field_views_handler_field {
    
     /**
   * An array to store field renderable arrays for use by render_items.
   *
   * @var array
   */
  public $items = array();

  /**
   * Store the field information.
   *
   * @var array
   */
  public $field_info = array();

  /**
   * Store the field component information.
   *
   * @var array
   */
  public $field_component_info = array();

  /**
   * Does the field supports multiple field values.
   *
   * @var bool
   */
  public $multiple;

  
  /**
   * A shortcut for $view->base_table.
   *
   * @var string
   */
  public $base_table;

  /**
   * Store the field instance.
   *
   * @var array
   */
  public $instance;

  function init(&$view, &$options) {
    parent::init($view, $options);

    $this->field_info = $field = field_info_field($this->definition['field_name']);
    $this->field_component_info = $this->load_field_component_info();
    $this->multiple = FALSE;
   
    

    if ($this->field_component_info['extra']['multiple']) {
      $this->multiple = TRUE;
    }
 
    module_load_include('inc', 'questions_field', 'components/select');
    $this->items =  _questions_field_select_options($this->field_component_info);
  }
 


function option_definition() {
    $options = parent::option_definition();
 

    $options['delta_limit'] = array(
      'default' => 'all',
    );
    $options['delta_offset'] = array(
      'default' => 0,
    );
    $options['delta_reversed'] = array(
      'default' => FALSE,
      'bool' => TRUE,
    );
    $options['delta_first_last'] = array(
      'default' => FALSE,
      'bool' => TRUE,
    );

    $options['multi_type'] = array(
      'default' => 'separator'
    );
    $options['separator'] = array(
      'default' => ', '
    );

    return $options;
  }
  
function load_field_component_info() {
        $field = $this->field_info;
        $real_field = $this->field;
        $cid = str_replace($field['field_name'] . '_', '', $real_field);
        $components = questions_field_field_components_load($field, array($cid));
        $field_component_info = $components[$cid];
        questions_field_component_defaults($field_component_info);
        return $field_component_info;
}
  
   /**
   * Provide options for multiple value fields.
   */
  function multiple_options_form(&$form, &$form_state) {

    $form['multiple_field_settings'] = array(
      '#type' => 'fieldset',
      '#title' => t('Multiple field settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#weight' => 5,
    );

    // Make the string translatable by keeping it as a whole rather than
    // translating prefix and suffix separately.
    list($prefix, $suffix) = explode('@count', t('Display @count value(s)'));
 
    $type = 'textfield';
    $options = NULL;
    $size = 5;
    
    $form['multi_type'] = array(
      '#type' => 'radios',
      '#title' => t('Display type'),
      '#options' => array(
        'ul' => t('Unordered list'),
        'ol' => t('Ordered list'),
        'separator' => t('Simple separator'),
      ),
      '#default_value' => $this->options['multi_type'],
      '#fieldset' => 'multiple_field_settings',
    );

    $form['separator'] = array(
      '#type' => 'textfield',
      '#title' => t('Separator'),
      '#default_value' => $this->options['separator'],
      '#states' => array(
                'visible' => array(
                    ':input[name="options[multi_type]"]' => array('value' => 'separator'),
                ),
            ),
       '#fieldset' => 'multiple_field_settings',
    );

    $form['delta_limit'] = array(
      '#type' => $type,
      '#size' => $size,
      '#field_prefix' => $prefix,
      '#field_suffix' => $suffix,
      '#options' => $options,
      '#default_value' => $this->options['delta_limit'],
      '#prefix' => '<div class="container-inline">',
      '#fieldset' => 'multiple_field_settings',
    );

    list($prefix, $suffix) = explode('@count', t('starting from @count'));
    $form['delta_offset'] = array(
      '#type' => 'textfield',
      '#size' => 5,
      '#field_prefix' => $prefix,
      '#field_suffix' => $suffix,
      '#default_value' => $this->options['delta_offset'],
      '#description' => t('(first item is 0)'),
      '#fieldset' => 'multiple_field_settings',
    );
    $form['delta_reversed'] = array(
      '#title' => t('Reversed'),
      '#type' => 'checkbox',
      '#default_value' => $this->options['delta_reversed'],
      '#suffix' => $suffix,
      '#description' => t('(start from last values)'),
      '#fieldset' => 'multiple_field_settings',
    );
    $form['delta_first_last'] = array(
      '#title' => t('First and last only'),
      '#type' => 'checkbox',
      '#default_value' => $this->options['delta_first_last'],
      '#suffix' => '</div>',
      '#fieldset' => 'multiple_field_settings',
    );
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    // If this is a multiple value field, add its options.
    if ($this->multiple) {
      $this->multiple_options_form($form, $form_state);
    }

  }

      /**
   * Render the field.
   *
   * @param $values
   *   The values retrieved from the database.
   */
  function render($values) {

        $component = $this->load_component($values);
        $value = $this->get_value($values);
        if ($this->multiple) {
            $multiple_settings = array(
                'delta_limit' => $this->options['delta_limit'],
                'delta_offset' => $this->options['delta_offset'],
                'delta_reversed' => $this->options['delta_reversed'],
                'delta_first_last' => $this->options['delta_first_last'],
                'multi_type' => $this->options['multi_type'],
                'separator' => $this->options['separator'],
            );
            $component['multiple_settings'] = $multiple_settings;
        }
        $component['extra']['title_display'] = ($this->options['display_question']) ? $this->options['display_question'] : $component['extra']['title_display'];

        return questions_field_component_invoke($component['type'], 'display', $component, $value);
    }


}

